@@ -119,7 +119,7 @@ class AkeneoProduct:
         """
         return self.values.get(attribute, [])
     
-    def get_value(self, attribute: str, locale: str | None = None, scope: str | None = None) -> Value:
+    def get_value(self, attribute: str, locale: str | None = None, scope: str | None = None) -> any:
         """
         Gets the value for the given attribute.
 
@@ -129,7 +129,7 @@ class AkeneoProduct:
             scope (str): The scope of the value.
 
         Returns:
-            str: The value of the attribute.
+            str: The value of the attribute. None if not found.
         """
         # Failsafe
         if attribute not in self.values:
@@ -140,9 +140,40 @@ class AkeneoProduct:
             if value.get('locale') == locale and value.get('scope') == scope:
                 return value.get('data')
 
-        # Return the first value if locale and scope are not found
-        return self.values[attribute][0].get('data')
+        # Return first value if locale is None and scope is None
+        if locale is None and scope is None:
+            return self.values[attribute][0].get('data')
+        
+        # Return None if locale and scope are not found
+        return None
     
+    def get_href(self, attribute: str, locale: str | None = None, scope: str | None = None) -> str | None:
+        """
+        Gets the link for a downloadable attribute.
+
+        Args:
+            attribute (str): The attribute to get the link for.
+            locale (str): The locale of the value.
+            scope (str): The scope of the value.
+
+        Returns:
+            dict: The link of the attribute. None if not found.
+        """
+        # Failsafe
+        if attribute not in self.values:
+            return None
+
+        # Try to find the value with locale and scope
+        for value in self.values[attribute]:
+            if value.get('locale') == locale and value.get('scope') == scope:
+                return value.get('_links', {}).get('download', {}).get('href', None)
+
+        # Return first value if locale is None and scope is None
+        if locale is None and scope is None:
+            return self.values[attribute][0].get('_links', {}).get('download', {}).get('href', None)
+        
+        # Return None if locale and scope are not found
+        return None
 
     def set_value(self, attribute: str, locale: str | None = None, scope: str | None = None, data: str | None = None):
         """
@@ -223,14 +254,37 @@ class AkeneoProduct:
         Updates the product.
 
         Returns:
-            bool: True if successful, False otherwise.
+            bool: JSON response if successful, None otherwise.
         """
         # Build the URL
         url = self.connector.product_url.format(identifier=self.identifier)
 
         # Update the product
-        self.connector.update(url, self.payload())
+        return self.connector.update(url, self.payload())
 
-        return True
+    def create(self):
+        """
+        Creates the product.
 
-    
\ No newline at end of file
+        Returns:
+            bool: JSON response if successful, None otherwise.
+        """
+        #  Update is same
+        return self.update()
+    
+    def get_media(self, media_attribute: str, locale: str | None = None, scope: str | None = None):
+        """
+        Downloads the media file for the specified attribute.
+
+        Args:
+            image_attribute (str): The name of the attribute containing the image.
+            locale (str): The locale of the value.
+            scope (str): The scope of the value.
+
+        Returns:
+            bytes: The content of the media file, or None if not found
+        """
+        media_url = self.get_href(media_attribute, locale, scope)
+        if media_url:
+            return self.connector.get_media_file(media_url)
+        return None
\ No newline at end of file
